import { useEffect } from "react";
import PropTypes from "prop-types";
import { useSelector, useDispatch } from "react-redux";
import { Navigate, useLocation } from "react-router-dom";
import {
	Box,
	Container,
	Grid,
	Typography,
	Card,
	CardHeader,
	CardContent,
	InputAdornment,
	Button,
	CircularProgress,
	AppBar,
	Toolbar,
	Link
} from "@mui/material";
import { Email, Lock } from "@mui/icons-material";
import { Form } from "react-final-form";
import { TextField } from "@chimera-pe/mui-rff";
import { useTranslate } from "react-polyglot";
import { requestToken } from "../redux";
import { useCheckLogin, useNotificar } from "../hooks";

const FormularioLogin = ({ devURL }) => {
	const dispatch = useDispatch();
	const translate = useTranslate();
	const notificar = useNotificar();
	const { cargando, error } = useSelector(store => store.login);
	const instancia = useSelector(store => store.aplicacion.instancia);

	const submit = values => {
		dispatch(requestToken({
			devURL: devURL,
			clientCredentials: instancia.clientCredentials,
			data: {
				correo: values.correo,
				password: values.password
			}
		}));
	};

	const validate = values => {
		const errors = { correo: undefined, password: undefined };

		if (!values.correo) {
			errors.correo = translate("saas.login.validacion.correo");
		}
		if (!values.password) {
			errors.password = translate("saas.login.validacion.password");
		}
		return errors;
	};

	useEffect(() => {
		if (error) {
			notificar("saas.login.error", "error");
		}
	}, [notificar, error]);

	return (
		<Form
			onSubmit={submit}
			validate={validate}
			render={({ handleSubmit }) => (
				<form onSubmit={handleSubmit}>
					<TextField
						id="correo"
						name="correo"
						label={translate("saas.login.correo")}
						variant="outlined"
						autoComplete="off"
						disabled={cargando}
						autoFocus
						InputProps={{
							startAdornment: (
								<InputAdornment position="start">
									<Email color="primary" />
								</InputAdornment>
							)
						}}
					/>
					<TextField
						id="password"
						name="password"
						type="password"
						label={translate("saas.login.password")}
						variant="outlined"
						autoComplete="current-password"
						disabled={cargando}
						InputProps={{
							startAdornment: (
								<InputAdornment position="start">
									<Lock color="primary" />
								</InputAdornment>
							)
						}}
					/>
					<Grid container>
						<Grid item xs={6}></Grid>
						<Grid item xs={6} align="right">
							<Button
								variant="contained"
								color="primary"
								type="submit"
								disabled={cargando}
							>
								{cargando ?
									<CircularProgress size={24} thickness={4} />
									:
									translate("saas.login.ingresar")
								}
							</Button>
						</Grid>
					</Grid>
				</form>
			)}
		/>
	);
};

FormularioLogin.propTypes = {
	devURL: PropTypes.string
};

const Login = ({ devURL }) => {
	const instancia = useSelector(store => store.aplicacion.instancia);
	const translate = useTranslate();
	const location = useLocation();
	const autenticado = useCheckLogin(devURL);
	const { from } = location.state || { from: { pathname: "/" } };

	if (!instancia.requiereLogin || autenticado) {
		return <Navigate to={from} />;
	}

	return (
		<Box sx={{
			position: "relative",
			display: "flex",
			flexDirection: "column",
			flexGrow: 1,
			minHeight: "100vh",
			backgroundColor: "primary.main",
			"&::before": {
				content: '""',
				backgroundImage: `url(${instancia.logo})`,
				backgroundSize: "contain",
				backgroundRepeat: "no-repeat",
				backgroundPosition: "right",
				position: "absolute",
				top: "20%",
				bottom: 0,
				right: 0,
				width: "50%",
				opacity: 0.02,
				filter: "grayscale(100%)"
			}
		}}>
			<Box sx={{
				display: "flex",
				justifyContent: "center",
				alignItems: "center",
				flexGrow: 1
			}}>
				<Container maxWidth="md">
					<Grid container spacing={3}>
						<Grid item xs={12} lg={5} align="center">
							<img src={instancia.logo} alt={instancia.nombre} style={{ maxWidth: "100%" }} />
							<Typography variant="h3" align="center">{translate("aplicacion.nombre", { smart_count: 1 })}</Typography>
							<Typography variant="h5" align="center">{instancia.nombre}</Typography>
						</Grid>
						<Grid item xs={12} lg={7} sx={{
							display: "flex",
							alignItems: "center",
							justifyContent: "center",
							zIndex: 5
						}}>
							<Card elevation={5}>
								<CardHeader title={translate("saas.login.titulo")} titleTypographyProps={{ align: "center" }} />
								<CardContent sx={{
									"& .MuiTextField-root": {
										mb: 2
									},
								}}>
									<FormularioLogin devURL={devURL} />
								</CardContent>
							</Card>
						</Grid>
					</Grid>
				</Container>
			</Box>
			<AppBar position="static" color="primary">
				<Toolbar sx={{ justifyContent: "center" }}>
					<Typography variant="caption">
						{translate("saas.copy")}
						<Link href="//chimera.com.pe" color="inherit" target="_blank" rel="noreferrer">Chimera Software</Link>
					</Typography>
				</Toolbar>
			</AppBar>
		</Box>
	);
};

Login.propTypes = {
	devURL: PropTypes.string
};

export default Login;
